'''
..
  File: cmd.py
  generated: 2024-10-15T23:37:42+02:00
  generator: org.clazzes.remoting.remoting-maven-plugin-1.5.0-SNAPSHOT.
  Note: Use 'mvn process-sources' to regenerate this file.
'''

from clazzes.remoting.loading import ClassBytes
from clazzes.remoting.serializer import JavaObject
from collections.abc import Mapping
from clazzes.remoting.serializer import Serializer
from clazzes.remoting.throwable import Throwable
from clazzes.remoting.uid import UID


class Cmd(JavaObject):
    __slots__ = ()
    '''
      An on-the-wire  wire command of the remoting system with a visitor.

      @author wglas
    '''
    @staticmethod
    def getSerialID():
        return "org.clazzes.remoting.cmd.Cmd"

    @staticmethod
    def getSerialVersionUID():
        return 4639537525936918825

    def writeFields(self,srlzr:Serializer):
        pass

    def readFields(self,srlzr:Serializer, serialVersionUID:int):  # @UnusedVariable
        pass

class CallBackCmd(Cmd):
    __slots__ = ("arg","callbackUID","metadata")
    '''

      @author wglas

      :ivar callbackUID: The UID of the callback being invoked.

      :ivar arg: The argument to the subsystem.

      :ivar metadata: The metadata passed to the {@link InvocationHandler}
    '''
    callbackUID: UID
    arg: object
    metadata: Mapping[str,object]

    @staticmethod
    def getSerialID():
        return "org.clazzes.remoting.cmd.CallBackCmd"

    @staticmethod
    def getSerialVersionUID():
        return 2249775601424926139

    def __init__(self):
        super().__init__()
        self.arg = None
        self.callbackUID = None
        self.metadata = None

    def writeFields(self,srlzr:Serializer):
        srlzr.writeObject("arg",self.arg)
        srlzr.writeObject("callbackUID",self.callbackUID)
        srlzr.writeObject("metadata",self.metadata)
        super().writeFields(srlzr)

    def readFields(self,srlzr:Serializer, serialVersionUID:int):  # @UnusedVariable
        self.arg = srlzr.readObject("arg")
        self.callbackUID = srlzr.readObject("callbackUID")
        self.metadata = srlzr.readObject("metadata")
        superId = Cmd.getSerialVersionUID()
        super().readFields(srlzr,superId)

class ExchangeClientUIDCmd(Cmd):
    __slots__ = ("clientUID")
    '''
      A command, which is sent from the server to the client, when a connection is established.

      @author wglas

      :ivar clientUID: The result of an invocation.
    '''
    clientUID: UID

    @staticmethod
    def getSerialID():
        return "org.clazzes.remoting.cmd.ExchangeClientUIDCmd"

    @staticmethod
    def getSerialVersionUID():
        return 8820061169344987973

    def __init__(self):
        super().__init__()
        self.clientUID = None

    def writeFields(self,srlzr:Serializer):
        srlzr.writeObject("clientUID",self.clientUID)
        super().writeFields(srlzr)

    def readFields(self,srlzr:Serializer, serialVersionUID:int):  # @UnusedVariable
        self.clientUID = srlzr.readObject("clientUID")
        superId = Cmd.getSerialVersionUID()
        super().readFields(srlzr,superId)

class InvocationCmd(Cmd):
    __slots__ = ("arg","metadata","subSystem")
    '''
      An invocation command is sent over the wire from the client to the server upon
      invocation of a remote call.

      The server initiates an InvocationCmd when a broadcast is sent from the server
      to all connected clients.

      @author wglas

      :ivar subSystem: The subsystem being called.

      :ivar arg: The argument to the subsystem.

      :ivar metadata: The metadata passed to the {@link InvocationHandler}
    '''
    subSystem: str
    arg: object
    metadata: Mapping[str,object]

    @staticmethod
    def getSerialID():
        return "org.clazzes.remoting.cmd.InvocationCmd"

    @staticmethod
    def getSerialVersionUID():
        return 2249775601424926139

    def __init__(self):
        super().__init__()
        self.arg = None
        self.metadata = None
        self.subSystem = None

    def writeFields(self,srlzr:Serializer):
        srlzr.writeObject("arg",self.arg)
        srlzr.writeObject("metadata",self.metadata)
        srlzr.writeObject("subSystem",self.subSystem)
        super().writeFields(srlzr)

    def readFields(self,srlzr:Serializer, serialVersionUID:int):  # @UnusedVariable
        self.arg = srlzr.readObject("arg")
        self.metadata = srlzr.readObject("metadata")
        self.subSystem = srlzr.readObject("subSystem")
        superId = Cmd.getSerialVersionUID()
        super().readFields(srlzr,superId)

class InvocationExceptionCmd(Cmd):
    __slots__ = ("exception")
    '''
      A command that is sent, when an invocation raised an exception.

      @author wglas

      :ivar exception: The result of an invocation.
    '''
    exception: Throwable

    @staticmethod
    def getSerialID():
        return "org.clazzes.remoting.cmd.InvocationExceptionCmd"

    @staticmethod
    def getSerialVersionUID():
        return -6565844600425860788

    def __init__(self):
        super().__init__()
        self.exception = None

    def writeFields(self,srlzr:Serializer):
        srlzr.writeObject("exception",self.exception)
        super().writeFields(srlzr)

    def readFields(self,srlzr:Serializer, serialVersionUID:int):  # @UnusedVariable
        self.exception = srlzr.readObject("exception")
        superId = Cmd.getSerialVersionUID()
        super().readFields(srlzr,superId)

class InvocationResultCmd(Cmd):
    __slots__ = ("result")
    '''
      A command, which is setnt, when an invocation returned normally.

      @author wglas

      :ivar result: The result of an invocation.
    '''
    result: object

    @staticmethod
    def getSerialID():
        return "org.clazzes.remoting.cmd.InvocationResultCmd"

    @staticmethod
    def getSerialVersionUID():
        return 4660903407307724568

    def __init__(self):
        super().__init__()
        self.result = None

    def writeFields(self,srlzr:Serializer):
        srlzr.writeObject("result",self.result)
        super().writeFields(srlzr)

    def readFields(self,srlzr:Serializer, serialVersionUID:int):  # @UnusedVariable
        self.result = srlzr.readObject("result")
        superId = Cmd.getSerialVersionUID()
        super().readFields(srlzr,superId)

class LoadClassCmd(Cmd):
    __slots__ = ("className")
    '''
      A command that requires a remote class being loaded.

      @author wglas

      :ivar className: The subsystem being called.
    '''
    className: str

    @staticmethod
    def getSerialID():
        return "org.clazzes.remoting.cmd.LoadClassCmd"

    @staticmethod
    def getSerialVersionUID():
        return 3347217843399443299

    def __init__(self):
        super().__init__()
        self.className = None

    def writeFields(self,srlzr:Serializer):
        srlzr.writeObject("className",self.className)
        super().writeFields(srlzr)

    def readFields(self,srlzr:Serializer, serialVersionUID:int):  # @UnusedVariable
        self.className = srlzr.readObject("className")
        superId = Cmd.getSerialVersionUID()
        super().readFields(srlzr,superId)

class ReturnClassBytesCmd(Cmd):
    __slots__ = ("classBytes")
    '''
      A command that reports a remote class to the client.

      @author wglas

      :ivar classBytes: The subsystem being called.
    '''
    classBytes: ClassBytes

    @staticmethod
    def getSerialID():
        return "org.clazzes.remoting.cmd.ReturnClassBytesCmd"

    @staticmethod
    def getSerialVersionUID():
        return 2641561482451151631

    def __init__(self):
        super().__init__()
        self.classBytes = None

    def writeFields(self,srlzr:Serializer):
        srlzr.writeObject("classBytes",self.classBytes)
        super().writeFields(srlzr)

    def readFields(self,srlzr:Serializer, serialVersionUID:int):  # @UnusedVariable
        self.classBytes = srlzr.readObject("classBytes")
        superId = Cmd.getSerialVersionUID()
        super().readFields(srlzr,superId)

SERIAL_IDS = {
    Cmd.getSerialID(): Cmd,
    CallBackCmd.getSerialID(): CallBackCmd,
    ExchangeClientUIDCmd.getSerialID(): ExchangeClientUIDCmd,
    InvocationCmd.getSerialID(): InvocationCmd,
    InvocationExceptionCmd.getSerialID(): InvocationExceptionCmd,
    InvocationResultCmd.getSerialID(): InvocationResultCmd,
    LoadClassCmd.getSerialID(): LoadClassCmd,
    ReturnClassBytesCmd.getSerialID(): ReturnClassBytesCmd
}
