'''
..
  $Id$
  
  Remoting python tools of the clazzes.org project
  http://www.clazzes.org
 
  Created: 04.02.2018
 
  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at
 
      http://www.apache.org/licenses/LICENSE-2.0
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
'''

from clazzes.tools import datetools
from clazzes.remoting import serializer

import datetime
import pytz

class UtcTimestamp(serializer.JavaObject,datetime.datetime):
    
    @staticmethod
    def getSerialVersionUID():
        return -4171006885461716579
    
    @staticmethod
    def getSerialID():
        return "org.clazzes.util.datetime.UtcTimestamp"
    
    def __str__(self):
        return datetools.format_datetime(self)
    
    @classmethod
    def readInstance(cls:type,srlzr:serializer.Serializer,serialVersionUID:int):  # @UnusedVariable
    
        tz_off = srlzr.readInt("tz_off")
        utcMillis = srlzr.readLong("utcMillis")

        if tz_off is None:
            tz = None
        else:
            tz = pytz.FixedOffset(tz_off)

        ret = cls.fromtimestamp(utcMillis*0.001,tz = tz)
        
        if not isinstance(ret,UtcTimestamp):
            ret = UtcTimestamp(ret.year,ret.month,ret.day,ret.hour,ret.minute,ret.second,ret.microsecond,ret.tzinfo)
        
        return ret

    def readFields(self,srlzr:serializer.Serializer,serialVersionUID:int):  # @UnusedVariable
        raise NotImplementedError("Use static UtcTimestamp.readInstance()")

    def writeFields(self, srlzr:serializer.Serializer):
        
        utcMillis = round(self.timestamp() * 1000)
        tz_off = self.utcoffset()
        
        if tz_off is not None:
            tz_off = int(tz_off.total_seconds()//60)
        
        srlzr.writeInt("tz_off",tz_off);
        srlzr.writeLong("utcMillis",utcMillis);

SERIAL_IDS = {
    UtcTimestamp.getSerialID(): UtcTimestamp
}