'''
..
  $Id$

  Remoting python tools of the clazzes.org project
  http://www.clazzes.org

  Created: 04.02.2018

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
'''

from clazzes.remoting import serializer
from urllib import parse

class URL(serializer.JavaObject):

    __slots__ = [ "_components" ]

    def __init__(self,url=''):
        self._components = parse.urlparse(url)

    @staticmethod
    def getSerialVersionUID():
        return -7627629688361524110

    @staticmethod
    def getSerialID():
        return "java.net.URL"

    def __str__(self):
        return self._components.geturl()

    def __repr__(self):
        return "<clazzes.remoting.url.URL \"%s\">"%self._components.geturl()

    def __hash__(self):
        return hash(self._components)

    def __eq__(self,other):
        return self._components == other._components

    def __getattr__(self,name):
        return getattr(self._components,name)

    def readFields(self,srlzr:serializer.Serializer,serialVersionUID:int):  # @UnusedVariable

        authority = srlzr.readObject("authority")
        file = srlzr.readObject("file")
        host = srlzr.readObject("host")
        port = srlzr.readInt("port")
        protocol = srlzr.readObject("protocol")
        reference = srlzr.readObject("reference")

        if port is None or port < 0:
            if authority is None:
                netloc = host
            else:
                netloc = "%s@%s"%(authority,host)
        else:
            if authority is None:
                netloc = "%s:%d"%(host,port)
            else:
                netloc = "%s@%s:%d"%(authority,host,port)

        i = file.find('?')

        if i<0:
            path = file
            query = ''
        else:
            path = file[0:i]
            query = file[i+1:]

        self._components = parse.ParseResult(protocol,netloc,path,'',query,reference)

    def writeFields(self, srlzr:serializer.Serializer):

        nl = self.netloc

        i = nl.find('@')

        if i < 0:
            authority = None
            hostport = nl
        else:
            authority = nl[0:i]
            hostport = nl[i+1:]

        i = hostport.find(':')

        if i < 0:
            host = hostport
            port = -1
        else:
            host = hostport[0:i]
            port = int(hostport[i+1:])

        if self.query:
            file = "%s?%s"%(self.path,self.query)
        else:
            file = self.path

        srlzr.writeObject("authority",authority);
        srlzr.writeObject("file",file);
        srlzr.writeObject("host",host);
        srlzr.writeInt("port",port);
        srlzr.writeObject("protocol",self.scheme);
        srlzr.writeObject("reference",self.fragment);

SERIAL_IDS = {
    URL.getSerialID(): URL
}